@@ -1,6 +1,8 @@
 var stylus = require('stylus'),
     nib = require('nib'),
-    source = '';
+    source = '',
+    filename = process.argv[2],
+    paths = process.argv.slice(3);
 
 process.stdin.resume();
 process.stdin.setEncoding('utf8');
@@ -10,7 +12,9 @@ process.stdin.on('data', function(chunk) {
 });
 
 process.stdin.on('end', function() {
-  var style = stylus(source, {filename: process.argv[2]}).use(nib());
+  var style = stylus(source, {filename: filename}).use(nib());
+  paths.map(style.include, style);
+
   style.render(function(err, css) {
     if (err) {
       throw err;
